@@ -1,7 +1,3 @@
 package DBICNSTest::RSet::A;
-
-use warnings;
-use strict;
-
 use base qw/DBIx::Class::ResultSet/;
 1;
